Welcome to xHydro's documentation!
==================================

.. toctree::
   :maxdepth: 2
   :caption: Contents:
   :hidden:

   readme
   installation
   usage
   notebooks/local_frequency_analysis
   notebooks/climate_change
   planification
   apidoc/modules
   contributing
   authors
   changes

.. toctree::
   :maxdepth: 1
   :caption: All Modules

   apidoc/modules

.. Indices and tables
.. ==================
.. * :ref:`genindex`
.. * :ref:`modindex`
.. * :ref:`search`
